/*
    Robot servo controller

    Gets data from the client and sends the data to a connected microcontroller

    (C) 2004 Jason Hunt

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

    Contact: huntjas2@msu.edu

    Compile with -lwsock32

    On windows 2000 and XP you must install a real mode port assess driver.
    I use "userport"

    FILE: key.cpp
*/


#include <windows.h>

#include "key.h"
#include "control.h"
#include "display.h"

int space_key = 0;          // keep track of the position of the space key


/* called when a key is pressed */
void process_key_down(WPARAM wParam)
{
    // escape key
    if (wParam == VK_ESCAPE) PostQuitMessage(0);

    // space resets the controller
    if (wParam == VK_SPACE && !space_key)
    {
        set_controller('S', 'S', 128, 128);
        space_key = 1;
    }


    // d key
    if (wParam == VK_TAB)
    {
        if (debug)
        {
            add_line("Leaving debug");
            debug = 0;
        }
        else
        {
            add_line("Entering debug");
            debug = 1;
        }
    }


    // space is manual override
    if (space_key)
    {
        if (wParam == VK_UP)    set_controller('F', 'F', 128, 128); else
        if (wParam == VK_DOWN)  set_controller('R', 'R', 128, 128); else
        if (wParam == VK_LEFT)  set_controller('R', 'F', 128, 128); else
        if (wParam == VK_RIGHT) set_controller('F', 'R', 128, 128);
    }
}
/* end of process key down */


/* called when a key is released */
void process_key_up( WPARAM wParam )
{
    if (wParam == VK_SPACE) space_key = 0;

    if (wParam == VK_UP || wParam == VK_DOWN || wParam == VK_LEFT || wParam == VK_RIGHT)
        set_controller('S', 'S', 128, 128);
}
/* end of process key up */




